#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class FunctionalSystemSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         FunctionalSystemSettingAtt
                | 
                | Enables attribute access to PFD options.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.functional_system_setting_att = com_object

    @property
    def document_content_at_creation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DocumentContentAtCreation() As long
                | 
                |     Returns or sets the DocumentContentAtCreation parameter.
                | 
                |     Parameters:
                | 
                |         iDocumentContentAtCreation
                |             oDocumentContentAtCreation Document Content At Creation Attribute
                |             Legal values:
                |             0 : Sample elements
                |             1: empty 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: int
        """

        return self.functional_system_setting_att.DocumentContentAtCreation

    @document_content_at_creation.setter
    def document_content_at_creation(self, value: int):
        """
        :param int value:
        """

        self.functional_system_setting_att.DocumentContentAtCreation = value

    @property
    def functional_action_presentation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FunctionalActionPresentation() As long
                | 
                |     Returns or sets the FunctionalActionPresentation
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iDocumentContentAtCreation
                |             or oDocumentContentAtCreation Functional Action Presentation Legal
                |             values:
                |             0 : A : Action
                |             1: SAO : Subject Action Object
                |             2: ASO : Action Subject Object 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: int
        """

        return self.functional_system_setting_att.FunctionalActionPresentation

    @functional_action_presentation.setter
    def functional_action_presentation(self, value: int):
        """
        :param int value:
        """

        self.functional_system_setting_att.FunctionalActionPresentation = value

    @property
    def show_parameters(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShowParameters() As long
                | 
                |     Returns or sets the ShowParameters parameter.
                | 
                |     Parameters:
                | 
                |         iShowParameters
                |             or oShowParameters Show Parameters Legal values:
                |             False :
                |             True: 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: int
        """

        return self.functional_system_setting_att.ShowParameters

    @show_parameters.setter
    def show_parameters(self, value: int):
        """
        :param int value:
        """

        self.functional_system_setting_att.ShowParameters = value

    @property
    def show_relations(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShowRelations() As long
                | 
                |     Returns or sets the ShowRelations parameter.
                | 
                |     Parameters:
                | 
                |         iShowRelations
                |             or oShowRelations Show Relations Legal values:
                |             False :
                |             True:

        :rtype: int
        """

        return self.functional_system_setting_att.ShowRelations

    @show_relations.setter
    def show_relations(self, value: int):
        """
        :param int value:
        """

        self.functional_system_setting_att.ShowRelations = value

    @property
    def show_synchro_status_of_local_param_cache(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShowSynchroStatusOfLocalParamCache() As long
                | 
                |     Returns or sets the ShowSynchroStatusOfLocalParamCache
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iShowSynchroStatusOfLocalParamCache
                |             or oShowSynchroStatusOfLocalParamCache Show Synchronisation Status
                |             OfLocal Parameter Cache Legal values:
                |             False :
                |             True :

        :rtype: int
        """

        return self.functional_system_setting_att.ShowSynchroStatusOfLocalParamCache

    @show_synchro_status_of_local_param_cache.setter
    def show_synchro_status_of_local_param_cache(self, value: int):
        """
        :param int value:
        """

        self.functional_system_setting_att.ShowSynchroStatusOfLocalParamCache = value

    @property
    def split_functional_object_name(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SplitFunctionalObjectName() As long
                | 
                |     Returns or sets the SplitFunctionalObjectName parameter.
                | 
                |     Parameters:
                | 
                |         iSplitFunctionalObjectName
                |             or oSplitFunctionalObjectName Legal values:
                |             False : don't split functional object name
                |             True : split Functional object name 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: int
        """

        return self.functional_system_setting_att.SplitFunctionalObjectName

    @split_functional_object_name.setter
    def split_functional_object_name(self, value: int):
        """
        :param int value:
        """

        self.functional_system_setting_att.SplitFunctionalObjectName = value

    @property
    def string_used_as_carriage_return(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StringUsedAsCarriageReturn() As CATBSTR
                | 
                |     Returns or sets the StringUsedAsCarriageReturn parameter.
                | 
                |     Parameters:
                | 
                |         iStringUsedAsCarriageReturn
                |             or oStringUsedAsCarriageReturn String Used As Carriage Return
                |             
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :rtype: str
        """

        return self.functional_system_setting_att.StringUsedAsCarriageReturn

    @string_used_as_carriage_return.setter
    def string_used_as_carriage_return(self, value: str):
        """
        :param str value:
        """

        self.functional_system_setting_att.StringUsedAsCarriageReturn = value

    @property
    def type_of_icon_on_functional_element(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TypeOfIconOnFunctionalElement() As long
                | 
                |     Returns or sets the TypeOfIconOnFunctionalElement
                |     parameter.
                | 
                |     Parameters:
                | 
                |         iTypeOfIconOnFunctionalElement
                |             or oTypeOfIconOnFunctionalElement Type Of Icon On Functional
                |             Elements Legal values:
                |             0 : indicate a current association with PPR links.
                |             1: indicate a current generative script.

        :rtype: int
        """

        return self.functional_system_setting_att.TypeOfIconOnFunctionalElement

    @type_of_icon_on_functional_element.setter
    def type_of_icon_on_functional_element(self, value: int):
        """
        :param int value:
        """

        self.functional_system_setting_att.TypeOfIconOnFunctionalElement = value

    def get_document_content_at_creation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDocumentContentAtCreationInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DocumentContentAtCreation
                |     parameter.
                |     Role:Retrieves the state of the DocumentContentAtCreation parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.functional_system_setting_att.GetDocumentContentAtCreationInfo(io_admin_level, io_locked)

    def get_functional_action_presentation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetFunctionalActionPresentationInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the FunctionalActionPresentation
                |     parameter.
                |     Role:Retrieves the state of the FunctionalActionPresentation parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.functional_system_setting_att.GetFunctionalActionPresentationInfo(io_admin_level, io_locked)

    def get_show_parameters_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetShowParametersInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ShowParameters
                |     parameter.
                |     Role:Retrieves the state of the ShowParameters parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.functional_system_setting_att.GetShowParametersInfo(io_admin_level, io_locked)

    def get_show_relations_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetShowRelationsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ShowRelations
                |     parameter.
                |     Role:Retrieves the state of the ShowRelations parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.functional_system_setting_att.GetShowRelationsInfo(io_admin_level, io_locked)

    def get_show_synchro_status_of_local_param_cache_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetShowSynchroStatusOfLocalParamCacheInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the
                |     ShowSynchroStatusOfLocalParamCache parameter.
                |     Role:Retrieves the state of the ShowSynchroStatusOfLocalParamCache
                |     parameter in the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.functional_system_setting_att.GetShowSynchroStatusOfLocalParamCacheInfo(io_admin_level, io_locked)

    def get_split_functional_object_name_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSplitFunctionalObjectNameInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SplitFunctionalObjectName
                |     parameter.
                |     Role:Retrieves the state of the SplitFunctionalObjectName parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.functional_system_setting_att.GetSplitFunctionalObjectNameInfo(io_admin_level, io_locked)

    def get_string_used_as_carriage_return_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStringUsedAsCarriageReturnInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the StringUsedAsCarriageReturn
                |     parameter.
                |     Role:Retrieves the state of the StringUsedAsCarriageReturn parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.functional_system_setting_att.GetStringUsedAsCarriageReturnInfo(io_admin_level, io_locked)

    def get_type_of_icon_on_functional_element_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTypeOfIconOnFunctionalElementInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TypeOfIconOnFunctionalElement
                |     parameter.
                |     Role:Retrieves the state of the TypeOfIconOnFunctionalElement parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.functional_system_setting_att.GetTypeOfIconOnFunctionalElementInfo(io_admin_level, io_locked)

    def set_document_content_at_creation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDocumentContentAtCreationLock(boolean iLocked)
                | 
                |     Locks or unlocks the DocumentContentAtCreation parameter.
                |     Role:Locks or unlocks the DocumentContentAtCreation parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.functional_system_setting_att.SetDocumentContentAtCreationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_document_content_at_creation_lock'
        # # vba_code = """
        # # Public Function set_document_content_at_creation_lock(functional_system_setting_att)
        # #     Dim iLocked (2)
        # #     functional_system_setting_att.SetDocumentContentAtCreationLock iLocked
        # #     set_document_content_at_creation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_functional_action_presentation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetFunctionalActionPresentationLock(boolean iLocked)
                | 
                |     Locks or unlocks the FunctionalActionPresentation
                |     parameter.
                |     Role:Locks or unlocks the FunctionalActionPresentation parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.functional_system_setting_att.SetFunctionalActionPresentationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_functional_action_presentation_lock'
        # # vba_code = """
        # # Public Function set_functional_action_presentation_lock(functional_system_setting_att)
        # #     Dim iLocked (2)
        # #     functional_system_setting_att.SetFunctionalActionPresentationLock iLocked
        # #     set_functional_action_presentation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_show_parameters_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetShowParametersLock(boolean iLocked)
                | 
                |     Locks or unlocks the ShowParameters parameter.
                |     Role:Locks or unlocks the ShowParameters parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.functional_system_setting_att.SetShowParametersLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_show_parameters_lock'
        # # vba_code = """
        # # Public Function set_show_parameters_lock(functional_system_setting_att)
        # #     Dim iLocked (2)
        # #     functional_system_setting_att.SetShowParametersLock iLocked
        # #     set_show_parameters_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_show_relations_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetShowRelationsLock(boolean iLocked)
                | 
                |     Locks or unlocks the ShowRelations parameter.
                |     Role:Locks or unlocks the ShowRelations parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.functional_system_setting_att.SetShowRelationsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_show_relations_lock'
        # # vba_code = """
        # # Public Function set_show_relations_lock(functional_system_setting_att)
        # #     Dim iLocked (2)
        # #     functional_system_setting_att.SetShowRelationsLock iLocked
        # #     set_show_relations_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_show_synchro_status_of_local_param_cache_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetShowSynchroStatusOfLocalParamCacheLock(boolean
                | iLocked)
                | 
                |     Locks or unlocks the ShowSynchroStatusOfLocalParamCache
                |     parameter.
                |     Role:Locks or unlocks the ShowSynchroStatusOfLocalParamCache parameter if
                |     it is possible in the current administrative context. In user mode this method
                |     will always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.functional_system_setting_att.SetShowSynchroStatusOfLocalParamCacheLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_show_synchro_status_of_local_param_cache_lock'
        # # vba_code = """
        # # Public Function set_show_synchro_status_of_local_param_cache_lock(functional_system_setting_att)
        # #     Dim iLocked (2)
        # #     functional_system_setting_att.SetShowSynchroStatusOfLocalParamCacheLock iLocked
        # #     set_show_synchro_status_of_local_param_cache_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_split_functional_object_name_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSplitFunctionalObjectNameLock(boolean iLocked)
                | 
                |     Locks or unlocks the SplitFunctionalObjectName parameter.
                |     Role:Locks or unlocks the SplitFunctionalObjectName parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.functional_system_setting_att.SetSplitFunctionalObjectNameLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_split_functional_object_name_lock'
        # # vba_code = """
        # # Public Function set_split_functional_object_name_lock(functional_system_setting_att)
        # #     Dim iLocked (2)
        # #     functional_system_setting_att.SetSplitFunctionalObjectNameLock iLocked
        # #     set_split_functional_object_name_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_string_used_as_carriage_return_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStringUsedAsCarriageReturnLock(boolean iLocked)
                | 
                |     Locks or unlocks the StringUsedAsCarriageReturn parameter.
                |     Role:Locks or unlocks the StringUsedAsCarriageReturn parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.functional_system_setting_att.SetStringUsedAsCarriageReturnLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_string_used_as_carriage_return_lock'
        # # vba_code = """
        # # Public Function set_string_used_as_carriage_return_lock(functional_system_setting_att)
        # #     Dim iLocked (2)
        # #     functional_system_setting_att.SetStringUsedAsCarriageReturnLock iLocked
        # #     set_string_used_as_carriage_return_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_type_of_icon_on_functional_element_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTypeOfIconOnFunctionalElementLock(boolean iLocked)
                | 
                |     Locks or unlocks the TypeOfIconOnFunctionalElement
                |     parameter.
                |     Role:Locks or unlocks the TypeOfIconOnFunctionalElement parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.functional_system_setting_att.SetTypeOfIconOnFunctionalElementLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_type_of_icon_on_functional_element_lock'
        # # vba_code = """
        # # Public Function set_type_of_icon_on_functional_element_lock(functional_system_setting_att)
        # #     Dim iLocked (2)
        # #     functional_system_setting_att.SetTypeOfIconOnFunctionalElementLock iLocked
        # #     set_type_of_icon_on_functional_element_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'FunctionalSystemSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class ShiftedProfileTolerance(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ShiftedProfileTolerance
                | 
                | Interface for accessing shifted tolerance zone informations of a
                | TPS.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.shifted_profile_tolerance = com_object

    @property
    def shift_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ShiftValue() As double
                | 
                |     Retrieves or sets shift value of tolerance zone (in millimeters). The shift
                |     value is the distance between the toleranced surface and the median surface of
                |     tolerance zone. The value is always positive because shift side is given by
                |     GetShiftSide method.

        :rtype: float
        """

        return self.shifted_profile_tolerance.ShiftValue

    @shift_value.setter
    def shift_value(self, value: float):
        """
        :param float value:
        """

        self.shifted_profile_tolerance.ShiftValue = value

    def get_shift_direction(self, op_direction: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetShiftDirection(CATSafeArrayVariant opDirection)
                | 
                |     Retrieves the shift direction by two points.
                | 
                |     Parameters:
                | 
                |         opDirection
                |             The first 3 values of opDirection correspond to the X,Y and Z
                |             values of the start point respectively and the next 3 values correspond to the
                |             X, Y and Z values of the end point respectively. 
                | 
                |     Example:
                | 
                |           This example gets the start and end points in a VB
                |           Script
                |          Dim oTab(6) As CATSafeArrayVariant
                |          Set shiftTol = annotation.ShiftedProfileTolerance
                |          shiftTol.GetShiftDirection(oTab)
                |          oStream.Write "      Shifted Direction Start Point : "& oTab(0) & " " & oTab(1) & " " & oTab(2) & sLF
                |          oStream.Write "      Shifted Direction End Point : "& oTab(3) & " " & oTab(4) & " " & oTab(5) & sLF

        :param tuple op_direction:
        :rtype: tuple
        """
        return self.shifted_profile_tolerance.GetShiftDirection(op_direction)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_shift_direction'
        # # vba_code = """
        # # Public Function get_shift_direction(shifted_profile_tolerance)
        # #     Dim opDirection (2)
        # #     shifted_profile_tolerance.GetShiftDirection opDirection
        # #     get_shift_direction = opDirection
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_shift_side(self, op_point: tuple) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetShiftSide(CATSafeArrayVariant opPoint)
                | 
                |     Retrieves shift side.
                | 
                |     Parameters:
                | 
                |         opPoint
                |             a mathematical point located on the shift side of surface. The 3
                |             values of opPoint correspond to the X,Y and Z values of the point located on
                |             the shift side of surface. 
                | 
                |     Example:
                | 
                |           This example gets the shift side point in a VB
                |           Script
                |          Dim oShiftTab(3) As CATSafeArrayVariant
                |          Set shiftTol = annotation.ShiftedProfileTolerance
                |          shiftTol.GetShiftSide(oShiftTab)
                |          oStream.Write "      Shifted Side Point : "& oShiftTab(0) & " " & oShiftTab(1) & " " & oShiftTab(2) & sLF

        :param tuple op_point:
        :rtype: tuple
        """
        return self.shifted_profile_tolerance.GetShiftSide(op_point)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_shift_side'
        # # vba_code = """
        # # Public Function get_shift_side(shifted_profile_tolerance)
        # #     Dim opPoint (2)
        # #     shifted_profile_tolerance.GetShiftSide opPoint
        # #     get_shift_side = opPoint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ShiftedProfileTolerance(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_area import ArrangementArea
from pycatia.in_interfaces.move import Move
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ArrangementAreas(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ArrangementAreas
                | 
                | A Collection object for ArrangementArea objects.
                | Role: Use this interface to add, retrieve and remove ArrangementArea objects
                | from this collection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ArrangementArea)
        self.arrangement_areas = com_object

    def add_area(self, i_rel_axis: Move, i_position: tuple, i_height: float) -> ArrangementArea:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddArea(Move iRelAxis,
                | CATSafeArrayVariant iPosition,
                | double iHeight) As ArrangementArea
                | 
                |     Creates a ArrangementArea and adds it to the collection. The Area created
                |     will be without any contour. Hence only the height of the area is
                |     specified.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             Relative Axis to be considered. 
                |         iPosition
                |             Position information for the Area (rotation and location).
                |             
                |         iHeight
                |             Height of the Area. 
                | 
                |     Returns:
                |         The newly created ArrangementArea object that is also added to the
                |         collection.

        :param Move i_rel_axis:
        :param tuple i_position:
        :param float i_height:
        :rtype: ArrangementArea
        """
        return ArrangementArea(self.arrangement_areas.AddArea(i_rel_axis.com_object, i_position, i_height))

    def item(self, i_index: cat_variant) -> ArrangementArea:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ArrangementArea
                | 
                |     Returns the specified item of the collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementArea to retrieve from this
                |             collection.
                | 
                |             To retrieve a specific object by number, use the rank of the
                |             ArrangementArea in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To retrieve a specific
                |                 ArrangementArea by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved ArrangementArea object.
                | 
                |         Example:
                |             This example retrieves ArrangementArea, objArea1, of rank 1 under
                |             the Areas collection.
                | 
                |              Dim objArea1 As ArrangementArea
                |              Set objArea1= Areas.Item(1)

        :param cat_variant i_index:
        :rtype: ArrangementArea
        """
        return ArrangementArea(self.arrangement_areas.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes the specified ArrangementArea object from the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementArea to remove from this
                |             collection.
                | 
                |             To remove a specific object by number, use the rank of the
                |             ArrangementArea in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To remove a specific
                |                 ArrangementArea by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property.
                | 
                |         Example:
                |             This example removes ArrangementArea of rank 1 under the Areas
                |             collection.
                | 
                |              Areas.Remove(1)

        :param cat_variant i_index:
        :rtype: None
        """
        return self.arrangement_areas.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(arrangement_areas)
        # #     Dim iIndex (2)
        # #     arrangement_areas.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ArrangementAreas(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SchAnnotationBreak(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAnnotationBreak
                | 
                | Manage an annotation break operations.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_annotation_break = com_object

    def flip_over_line(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FlipOverLine()
                | 
                |     Mirror the symbol over the route segment line that ends in the connector on
                |     which the symbol is placed.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAnnotationBreak
                |           ...
                |          objThisIntf.FlipOverLine

        :rtype: None
        """
        return self.sch_annotation_break.FlipOverLine()

    def flip_over_orthogonal_line(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub FlipOverOrthogonalLine()
                | 
                |     Mirror the symbol over the line orthogonal to the route segment line that
                |     ends in the connector on which the symbol is placed and going through the
                |     connector's position.
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAnnotationBreak
                |           ...
                |          objThisIntf.FlipOverOrthogonalLine

        :rtype: None
        """
        return self.sch_annotation_break.FlipOverOrthogonalLine()

    def scale(self, i_db_scale_factor: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Scale(double iDbScaleFactor)
                | 
                |     Scale the symbol.
                | 
                |     Parameters:
                | 
                |         iDbScaleFactor
                |             The scale factor to scale the symbol by. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAnnotationBreak
                |          Dim dbVar1 As Double
                |           ...
                |          objThisIntf.ScaledbVar1

        :param float i_db_scale_factor:
        :rtype: None
        """
        return self.sch_annotation_break.Scale(i_db_scale_factor)

    def __repr__(self):
        return f'SchAnnotationBreak(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class VerifyTabSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         VerifTabSettingAtt

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.verify_tab_setting_att = com_object

    @property
    def all_resource_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AllResourceFilter() As long
                | 
                |     Returns or sets the value to signify Whether all the resources will appear
                |     during Process Navigation
                |     Role: Returns or sets the value to signify Whether all the resources will
                |     appear during Process Navigation

        :rtype: int
        """

        return self.verify_tab_setting_att.AllResourceFilter

    @all_resource_filter.setter
    def all_resource_filter(self, value: int):
        """
        :param int value:
        """

        self.verify_tab_setting_att.AllResourceFilter = value

    @property
    def auto_reframe_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AutoReframeFilter() As long
                | 
                |     Returns or sets the value to signify Whether the 'Auto Reframe' will happen
                |     during Process navigation
                |     Role: Returns or sets the value to signify Whether all the items/resources
                |     will be reframed during Process Navigation

        :rtype: int
        """

        return self.verify_tab_setting_att.AutoReframeFilter

    @auto_reframe_filter.setter
    def auto_reframe_filter(self, value: int):
        """
        :param int value:
        """

        self.verify_tab_setting_att.AutoReframeFilter = value

    @property
    def implied_resource_filter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ImpliedResourceFilter() As long
                | 
                |     Returns or sets the value to signify Whether the Assigned resource will
                |     appear during Process Navigation
                |     Role: Returns or sets the value to signify Whether all the Assigned
                |     resource will appear during Process Navigation

        :rtype: int
        """

        return self.verify_tab_setting_att.ImpliedResourceFilter

    @implied_resource_filter.setter
    def implied_resource_filter(self, value: int):
        """
        :param int value:
        """

        self.verify_tab_setting_att.ImpliedResourceFilter = value

    def get_all_resource_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAllResourceFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "View All Resources"
                |     parameter.
                |     Role:Retrieves the state of the "View All Resources" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.verify_tab_setting_att.GetAllResourceFilterInfo(io_admin_level, io_locked)

    def get_auto_reframe_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAutoReframeFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "Auto Reframe"
                |     parameter.
                |     Role:Retrieves the state of the "Auto Reframe" parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.verify_tab_setting_att.GetAutoReframeFilterInfo(io_admin_level, io_locked)

    def get_implied_resource_filter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetImpliedResourceFilterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the "View Implied Resource"
                |     parameter.
                |     Role:Retrieves the state of the "View Implied Resource" parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.verify_tab_setting_att.GetImpliedResourceFilterInfo(io_admin_level, io_locked)

    def set_all_resource_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAllResourceFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the "View All Resources" parameter.
                |     Role:Locks or unlocks the "View All Resources" parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.verify_tab_setting_att.SetAllResourceFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_all_resource_filter_lock'
        # # vba_code = """
        # # Public Function set_all_resource_filter_lock(verif_tab_setting_att)
        # #     Dim iLocked (2)
        # #     verif_tab_setting_att.SetAllResourceFilterLock iLocked
        # #     set_all_resource_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_auto_reframe_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAutoReframeFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the "Auto Reframe" parameter.
                |     Role:Locks or unlocks the "Auto Reframe" parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.verify_tab_setting_att.SetAutoReframeFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_auto_reframe_filter_lock'
        # # vba_code = """
        # # Public Function set_auto_reframe_filter_lock(verif_tab_setting_att)
        # #     Dim iLocked (2)
        # #     verif_tab_setting_att.SetAutoReframeFilterLock iLocked
        # #     set_auto_reframe_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_implied_resource_filter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetImpliedResourceFilterLock(boolean iLocked)
                | 
                |     Locks or unlocks the Xxx parameter.
                |     Role:Locks or unlocks the "View Implied Resource" parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.verify_tab_setting_att.SetImpliedResourceFilterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_implied_resource_filter_lock'
        # # vba_code = """
        # # Public Function set_implied_resource_filter_lock(verif_tab_setting_att)
        # #     Dim iLocked (2)
        # #     verif_tab_setting_att.SetImpliedResourceFilterLock iLocked
        # #     set_implied_resource_filter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'VerifTabSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.dimension import Dimension


class Angle(Dimension):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.Parameter
                |                         KnowledgeInterfaces.RealParam
                |                             KnowledgeInterfaces.Dimension
                |                                 Angle
                | 
                | Represents the angle parameter.
                | The following example shows how to create it:
                | 
                |  Dim CATDocs As Documents
                |  Set CATDocs = CATIA.Documents
                |  Dim part1 As Document
                |  Set part1   = CATDocs.Add("CATPart")
                |  Dim angle1 As Angle
                |  Set angle1  = part1.Parameters.CreateDimension("angle1", "ANGLE", 40.)
                |  
                | 
                | Copyright © 1999-2011, Dassault Systèmes. All rights reserved.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.angle = com_object

    def __repr__(self):
        return f'Angle(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class MultiCADSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         MultiCADSettingAtt

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.multi_cad_setting_att = com_object

    @property
    def annotation_3d_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Annotation3DMode() As boolean
                | 
                |     Returns or sets the Annotation 3D mode R18sp3 on env. variable

        :rtype: bool
        """

        return self.multi_cad_setting_att.Annotation3DMode

    @annotation_3d_mode.setter
    def annotation_3d_mode(self, value: bool):
        """
        :param bool value:
        """

        self.multi_cad_setting_att.Annotation3DMode = value

    @property
    def conversion_technology(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConversionTechnology() As long
                | 
                |     Returns or sets the Conversion Technology

        :rtype: int
        """

        return self.multi_cad_setting_att.ConversionTechnology

    @conversion_technology.setter
    def conversion_technology(self, value: int):
        """
        :param int value:
        """

        self.multi_cad_setting_att.ConversionTechnology = value

    @property
    def link_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LinkMode() As long
                | 
                |     Returns or sets the Link Mode

        :rtype: int
        """

        return self.multi_cad_setting_att.LinkMode

    @link_mode.setter
    def link_mode(self, value: int):
        """
        :param int value:
        """

        self.multi_cad_setting_att.LinkMode = value

    @property
    def output_path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property OutputPath() As CATBSTR
                | 
                |     Returns or sets the Output Path

        :rtype: str
        """

        return self.multi_cad_setting_att.OutputPath

    @output_path.setter
    def output_path(self, value: str):
        """
        :param str value:
        """

        self.multi_cad_setting_att.OutputPath = value

    @property
    def parts_parameter_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PartsParameterMode() As long
                | 
                |     Returns or sets the parts parameterization mode

        :rtype: int
        """

        return self.multi_cad_setting_att.PartsParameterMode

    @parts_parameter_mode.setter
    def parts_parameter_mode(self, value: int):
        """
        :param int value:
        """

        self.multi_cad_setting_att.PartsParameterMode = value

    @property
    def pro_e_instance_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ProEInstanceMode() As boolean
                | 
                |     Returns or sets the ProEInstanceMode

        :rtype: bool
        """

        return self.multi_cad_setting_att.ProEInstanceMode

    @pro_e_instance_mode.setter
    def pro_e_instance_mode(self, value: bool):
        """
        :param bool value:
        """

        self.multi_cad_setting_att.ProEInstanceMode = value

    @property
    def pro_e_instance_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ProEInstanceName() As CATBSTR
                | 
                |     Returns or sets the ProEInstanceName

        :rtype: str
        """

        return self.multi_cad_setting_att.ProEInstanceName

    @pro_e_instance_name.setter
    def pro_e_instance_name(self, value: str):
        """
        :param str value:
        """

        self.multi_cad_setting_att.ProEInstanceName = value

    @property
    def pro_e_quilts_read(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ProEQuiltsRead() As boolean
                | 
                |     Returns or sets the ProEQuiltsRead

        :rtype: bool
        """

        return self.multi_cad_setting_att.ProEQuiltsRead

    @pro_e_quilts_read.setter
    def pro_e_quilts_read(self, value: bool):
        """
        :param bool value:
        """

        self.multi_cad_setting_att.ProEQuiltsRead = value

    @property
    def pro_e_simp_rep_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ProESimpRepMode() As boolean
                | 
                |     Returns or sets the ProESimpRepMode

        :rtype: bool
        """

        return self.multi_cad_setting_att.ProESimpRepMode

    @pro_e_simp_rep_mode.setter
    def pro_e_simp_rep_mode(self, value: bool):
        """
        :param bool value:
        """

        self.multi_cad_setting_att.ProESimpRepMode = value

    @property
    def pro_e_simp_rep_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ProESimpRepName() As CATBSTR
                | 
                |     Returns or sets the ProESimpRepName

        :rtype: str
        """

        return self.multi_cad_setting_att.ProESimpRepName

    @pro_e_simp_rep_name.setter
    def pro_e_simp_rep_name(self, value: str):
        """
        :param str value:
        """

        self.multi_cad_setting_att.ProESimpRepName = value

    @property
    def save_coorsys_in_cgr(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SaveCoorsysInCgr() As boolean
                | 
                |     Returns or sets the Save Coordinate Systems in CGR

        :rtype: bool
        """

        return self.multi_cad_setting_att.SaveCoorsysInCgr

    @save_coorsys_in_cgr.setter
    def save_coorsys_in_cgr(self, value: bool):
        """
        :param bool value:
        """

        self.multi_cad_setting_att.SaveCoorsysInCgr = value

    @property
    def translator_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TranslatorMode() As long
                | 
                |     Returns or sets the Translator mode

        :rtype: int
        """

        return self.multi_cad_setting_att.TranslatorMode

    @translator_mode.setter
    def translator_mode(self, value: int):
        """
        :param int value:
        """

        self.multi_cad_setting_att.TranslatorMode = value

    @property
    def ug_active_layers_only(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UGActiveLayersOnly() As boolean
                | 
                |     Returns or sets the UGActiveLayersOnly

        :rtype: bool
        """

        return self.multi_cad_setting_att.UGActiveLayersOnly

    @ug_active_layers_only.setter
    def ug_active_layers_only(self, value: bool):
        """
        :param bool value:
        """

        self.multi_cad_setting_att.UGActiveLayersOnly = value

    @property
    def ug_drawing_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UGDrawingName() As CATBSTR
                | 
                |     Returns or sets the UGDrawingName

        :rtype: str
        """

        return self.multi_cad_setting_att.UGDrawingName

    @ug_drawing_name.setter
    def ug_drawing_name(self, value: str):
        """
        :param str value:
        """

        self.multi_cad_setting_att.UGDrawingName = value

    @property
    def ug_layer_numbers(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UGLayerNumbers() As CATBSTR
                | 
                |     Returns or sets the UGLayerNumbers

        :rtype: str
        """

        return self.multi_cad_setting_att.UGLayerNumbers

    @ug_layer_numbers.setter
    def ug_layer_numbers(self, value: str):
        """
        :param str value:
        """

        self.multi_cad_setting_att.UGLayerNumbers = value

    @property
    def ug_open_surfaces(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UGOpenSurfaces() As boolean
                | 
                |     Returns or sets the UGOpenSurfaces

        :rtype: bool
        """

        return self.multi_cad_setting_att.UGOpenSurfaces

    @ug_open_surfaces.setter
    def ug_open_surfaces(self, value: bool):
        """
        :param bool value:
        """

        self.multi_cad_setting_att.UGOpenSurfaces = value

    @property
    def ug_reference_set(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UgReferenceSet() As CATBSTR
                | 
                |     Returns or sets the UgReferenceSet

        :rtype: str
        """

        return self.multi_cad_setting_att.UgReferenceSet

    @ug_reference_set.setter
    def ug_reference_set(self, value: str):
        """
        :param str value:
        """

        self.multi_cad_setting_att.UgReferenceSet = value

    @property
    def visu_format_unit(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisuFormatUnit() As float
                | 
                |     Returns or sets the Unit for Visu Format (number of milimeters per unit of
                |     the file)

        :rtype: float
        """

        return self.multi_cad_setting_att.VisuFormatUnit

    @visu_format_unit.setter
    def visu_format_unit(self, value: float):
        """
        :param float value:
        """

        self.multi_cad_setting_att.VisuFormatUnit = value

    def get_annotation_3d_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnnotation3DModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Annotation3DMode
                |     parameter.
                |     Role:Retrieves the state of the Annotation3DMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetAnnotation3DModeInfo(io_admin_level, io_locked)

    def get_conversion_technology_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConversionTechnologyInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ConversionTechnology
                |     parameter.
                |     Role:Retrieves the state of the ConversionTechnology parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetConversionTechnologyInfo(io_admin_level, io_locked)

    def get_link_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLinkModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LinkMode
                |     parameter.
                |     Role:Retrieves the state of the LinkMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetLinkModeInfo(io_admin_level, io_locked)

    def get_output_path_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOutputPathInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the OutputPath
                |     parameter.
                |     Role:Retrieves the state of the OutputPath parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetOutputPathInfo(io_admin_level, io_locked)

    def get_parts_parameter_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPartsParameterModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PartsParameterMode
                |     parameter.
                |     Role:Retrieves the state of the PartsParameterMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetPartsParameterModeInfo(io_admin_level, io_locked)

    def get_pro_e_instance_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProEInstanceModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ProEInstanceMode
                |     parameter.
                |     Role:Retrieves the state of the ProEInstanceMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetProEInstanceModeInfo(io_admin_level, io_locked)

    def get_pro_e_instance_name_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProEInstanceNameInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ProEInstanceName
                |     parameter.
                |     Role:Retrieves the state of the ProEInstanceName parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetProEInstanceNameInfo(io_admin_level, io_locked)

    def get_pro_e_quilts_read_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProEQuiltsReadInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ProEQuiltsRead
                |     parameter.
                |     Role:Retrieves the state of the ProEQuiltsRead parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetProEQuiltsReadInfo(io_admin_level, io_locked)

    def get_pro_e_simp_rep_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProESimpRepModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ProESimpRepMode
                |     parameter.
                |     Role:Retrieves the state of the ProESimpRepMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetProESimpRepModeInfo(io_admin_level, io_locked)

    def get_pro_e_simp_rep_name_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProESimpRepNameInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ProESimpRepName
                |     parameter.
                |     Role:Retrieves the state of the ProESimpRepName parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetProESimpRepNameInfo(io_admin_level, io_locked)

    def get_save_coorsys_in_cgr_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSaveCoorsysInCgrInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SaveCoorsysInCgr
                |     parameter.
                |     Role:Retrieves the state of the SaveCoorsysInCgr parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetSaveCoorsysInCgrInfo(io_admin_level, io_locked)

    def get_translator_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTranslatorModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the Translator mode
                |     parameter.
                |     Role:Retrieves the state of the Translator mode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetTranslatorModeInfo(io_admin_level, io_locked)

    def get_ug_active_layers_only_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUGActiveLayersOnlyInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the UGActiveLayersOnly
                |     parameter.
                |     Role:Retrieves the state of the UGActiveLayersOnly parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetUGActiveLayersOnlyInfo(io_admin_level, io_locked)

    def get_ug_drawing_name_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUGDrawingNameInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the UGDrawingName
                |     parameter.
                |     Role:Retrieves the state of the UGDrawingName parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetUGDrawingNameInfo(io_admin_level, io_locked)

    def get_ug_layer_numbers_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUGLayerNumbersInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the UGLayerNumbers
                |     parameter.
                |     Role:Retrieves the state of the UGLayerNumbers parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetUGLayerNumbersInfo(io_admin_level, io_locked)

    def get_ug_open_surfaces_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUGOpenSurfacesInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the UGOpenSurfaces
                |     parameter.
                |     Role:Retrieves the state of the UGOpenSurfaces parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetUGOpenSurfacesInfo(io_admin_level, io_locked)

    def get_ug_reference_set_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUgReferenceSetInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the UgReferenceSet
                |     parameter.
                |     Role:Retrieves the state of the UgReferenceSet parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetUgReferenceSetInfo(io_admin_level, io_locked)

    def get_visu_format_unit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVisuFormatUnitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the VisuFormatUnit
                |     parameter.
                |     Role:Retrieves the state of the VisuFormatUnit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.multi_cad_setting_att.GetVisuFormatUnitInfo(io_admin_level, io_locked)

    def set_annotation_3d_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnnotation3DModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Annotation3DMode parameter.
                |     Role:Locks or unlocks the Annotation3DMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetAnnotation3DModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_annotation3_d_mode_lock'
        # # vba_code = """
        # # Public Function set_annotation3_d_mode_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetAnnotation3DModeLock iLocked
        # #     set_annotation3_d_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_conversion_technology_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConversionTechnologyLock(boolean iLocked)
                | 
                |     Locks or unlocks the ConversionTechnology parameter.
                |     Role:Locks or unlocks the ConversionTechnology parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetConversionTechnologyLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_conversion_technology_lock'
        # # vba_code = """
        # # Public Function set_conversion_technology_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetConversionTechnologyLock iLocked
        # #     set_conversion_technology_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_link_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLinkModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the LinkMode parameter.
                |     Role:Locks or unlocks the LinkMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetLinkModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_link_mode_lock'
        # # vba_code = """
        # # Public Function set_link_mode_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetLinkModeLock iLocked
        # #     set_link_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_output_path_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetOutputPathLock(boolean iLocked)
                | 
                |     Locks or unlocks the OutputPath parameter.
                |     Role:Locks or unlocks the OutputPath parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetOutputPathLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_output_path_lock'
        # # vba_code = """
        # # Public Function set_output_path_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetOutputPathLock iLocked
        # #     set_output_path_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_parts_parameter_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPartsParameterModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the PartsParameterMode parameter.
                |     Role:Locks or unlocks the PartsParameterMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetPartsParameterModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_parts_parameter_mode_lock'
        # # vba_code = """
        # # Public Function set_parts_parameter_mode_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetPartsParameterModeLock iLocked
        # #     set_parts_parameter_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pro_e_instance_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProEInstanceModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ProEInstanceMode parameter.
                |     Role:Locks or unlocks the ProEInstanceMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetProEInstanceModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pro_e_instance_mode_lock'
        # # vba_code = """
        # # Public Function set_pro_e_instance_mode_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetProEInstanceModeLock iLocked
        # #     set_pro_e_instance_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pro_e_instance_name_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProEInstanceNameLock(boolean iLocked)
                | 
                |     Locks or unlocks the ProEInstanceName parameter.
                |     Role:Locks or unlocks the ProEInstanceName parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetProEInstanceNameLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pro_e_instance_name_lock'
        # # vba_code = """
        # # Public Function set_pro_e_instance_name_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetProEInstanceNameLock iLocked
        # #     set_pro_e_instance_name_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pro_e_quilts_read_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProEQuiltsReadLock(boolean iLocked)
                | 
                |     Locks or unlocks the ProEQuiltsRead parameter.
                |     Role:Locks or unlocks the ProEQuiltsRead parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetProEQuiltsReadLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pro_e_quilts_read_lock'
        # # vba_code = """
        # # Public Function set_pro_e_quilts_read_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetProEQuiltsReadLock iLocked
        # #     set_pro_e_quilts_read_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pro_e_simp_rep_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProESimpRepModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ProESimpRepMode parameter.
                |     Role:Locks or unlocks the ProESimpRepMode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetProESimpRepModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pro_e_simp_rep_mode_lock'
        # # vba_code = """
        # # Public Function set_pro_e_simp_rep_mode_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetProESimpRepModeLock iLocked
        # #     set_pro_e_simp_rep_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_pro_e_simp_rep_name_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProESimpRepNameLock(boolean iLocked)
                | 
                |     Locks or unlocks the ProESimpRepName parameter.
                |     Role:Locks or unlocks the ProESimpRepName parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetProESimpRepNameLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_pro_e_simp_rep_name_lock'
        # # vba_code = """
        # # Public Function set_pro_e_simp_rep_name_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetProESimpRepNameLock iLocked
        # #     set_pro_e_simp_rep_name_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_save_coorsys_in_cgr_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSaveCoorsysInCgrLock(boolean iLocked)
                | 
                |     Locks or unlocks the SaveCoorsysInCgr parameter.
                |     Role:Locks or unlocks the SaveCoorsysInCgr parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetSaveCoorsysInCgrLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_save_coorsys_in_cgr_lock'
        # # vba_code = """
        # # Public Function set_save_coorsys_in_cgr_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetSaveCoorsysInCgrLock iLocked
        # #     set_save_coorsys_in_cgr_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_translator_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTranslatorModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Translator mode parameter.
                |     Role:Locks or unlocks the Translator mode parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetTranslatorModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_translator_mode_lock'
        # # vba_code = """
        # # Public Function set_translator_mode_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetTranslatorModeLock iLocked
        # #     set_translator_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ug_active_layers_only_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUGActiveLayersOnlyLock(boolean iLocked)
                | 
                |     Locks or unlocks the UGActiveLayersOnly parameter.
                |     Role:Locks or unlocks the UGActiveLayersOnly parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetUGActiveLayersOnlyLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ug_active_layers_only_lock'
        # # vba_code = """
        # # Public Function set_ug_active_layers_only_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetUGActiveLayersOnlyLock iLocked
        # #     set_ug_active_layers_only_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ug_drawing_name_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUGDrawingNameLock(boolean iLocked)
                | 
                |     Locks or unlocks the UGDrawingName parameter.
                |     Role:Locks or unlocks the UGDrawingName parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetUGDrawingNameLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ug_drawing_name_lock'
        # # vba_code = """
        # # Public Function set_ug_drawing_name_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetUGDrawingNameLock iLocked
        # #     set_ug_drawing_name_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ug_layer_numbers_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUGLayerNumbersLock(boolean iLocked)
                | 
                |     Locks or unlocks the UGLayerNumbers parameter.
                |     Role:Locks or unlocks the UGLayerNumbers parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetUGLayerNumbersLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ug_layer_numbers_lock'
        # # vba_code = """
        # # Public Function set_ug_layer_numbers_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetUGLayerNumbersLock iLocked
        # #     set_ug_layer_numbers_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ug_open_surfaces_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUGOpenSurfacesLock(boolean iLocked)
                | 
                |     Locks or unlocks the UGOpenSurfaces parameter.
                |     Role:Locks or unlocks the UGOpenSurfaces parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetUGOpenSurfacesLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ug_open_surfaces_lock'
        # # vba_code = """
        # # Public Function set_ug_open_surfaces_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetUGOpenSurfacesLock iLocked
        # #     set_ug_open_surfaces_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_ug_reference_set_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUgReferenceSetLock(boolean iLocked)
                | 
                |     Locks or unlocks the UgReferenceSet parameter.
                |     Role:Locks or unlocks the UgReferenceSet parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetUgReferenceSetLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_ug_reference_set_lock'
        # # vba_code = """
        # # Public Function set_ug_reference_set_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetUgReferenceSetLock iLocked
        # #     set_ug_reference_set_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_visu_format_unit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVisuFormatUnitLock(boolean iLocked)
                | 
                |     Locks or unlocks the VisuFormatUnit parameter.
                |     Role:Locks or unlocks the VisuFormatUnit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.multi_cad_setting_att.SetVisuFormatUnitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_visu_format_unit_lock'
        # # vba_code = """
        # # Public Function set_visu_format_unit_lock(multi_cad_setting_att)
        # #     Dim iLocked (2)
        # #     multi_cad_setting_att.SetVisuFormatUnitLock iLocked
        # #     set_visu_format_unit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MultiCADSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class DnbAttachment(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNBAttachment
                | 
                | Interface representing xxx.
                | 
                | Role: Components that implement DNBIABasicDevice are ...
                | 
                | Do not use the DNBIAMRLAttachment interface for such and such ClassReference,
                | Class#MethodReference, #InternalMethod...
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dnb_attachment = com_object

    def get_child(self, o_child: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetChild(Product oChild)
                | 
                |     Get the Child Product of the Attachment.
                | 
                |     Parameters:
                | 
                |         oChild
                |             This out parameter contains the Child Product . 
                | 
                |     Returns:
                |         HRESULT indicate whether function succeed.

        :param Product o_child:
        :rtype: None
        """
        return self.dnb_attachment.GetChild(o_child.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_child'
        # # vba_code = """
        # # Public Function get_child(dnb_attachment)
        # #     Dim oChild (2)
        # #     dnb_attachment.GetChild oChild
        # #     get_child = oChild
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_child_ma(self, o_child_ma: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetChildMA(CATBaseDispatch oChildMA)
                | 
                |     Get the Child Manufacturing Assembly of the Attachment
                | 
                |     Parameters:
                | 
                |         oChildMA
                |             This out parameter contains Child Manufacturing Assembly of the
                |             Attachment . 
                | 
                |     Returns:
                |         HRESULT indicate whether function succeeded. It fails if the Child is
                |         not a Manufacturing Assembly

        :param AnyObject o_child_ma:
        :rtype: None
        """
        return self.dnb_attachment.GetChildMA(o_child_ma.com_object)

    def get_parent(self, o_parent: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetParent(Product oParent)
                | 
                |     Get the Parent Product of the Attachment.
                | 
                |     Parameters:
                | 
                |         oParent
                |             This outer parameter contains the Parent Product .
                |             
                | 
                |     Returns:
                |         An HRESULT

        :param Product o_parent:
        :rtype: None
        """
        return self.dnb_attachment.GetParent(o_parent.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_parent'
        # # vba_code = """
        # # Public Function get_parent(dnb_attachment)
        # #     Dim oParent (2)
        # #     dnb_attachment.GetParent oParent
        # #     get_parent = oParent
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_parent_ma(self, o_parent_ma: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetParentMA(CATBaseDispatch oParentMA)
                | 
                |     Get the Parent Manufacturing Assembly of the Attachment.
                | 
                |     Parameters:
                | 
                |         oParentMA
                |             This out parameter contains the Parent MA of the attachment .
                |             
                |         idbTrans
                |             This parameter contains distance data in Meters or angular data in
                |             degree radian. 
                | 
                |     Returns:
                |         HRESULT indicate whether function succeed. It fails if the Parent is
                |         not a Manufacturing Assembly

        :param AnyObject o_parent_ma:
        :rtype: None
        """
        return self.dnb_attachment.GetParentMA(o_parent_ma.com_object)

    def is_child_ma(self, i_child_ma: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsChildMA(boolean iChildMA)
                | 
                |     Get whether the Child is a Manufacturing Assembly
                | 
                |     Parameters:
                | 
                |         iChildMA
                |             TRUE if child is MA, FALSE otherwise 
                | 
                |     Returns:
                |         HRESULT indicate whether function succeeded. It fails if the Child is
                |         not a Manufacturing Assembly

        :param bool i_child_ma:
        :rtype: None
        """
        return self.dnb_attachment.IsChildMA(i_child_ma)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_child_ma'
        # # vba_code = """
        # # Public Function is_child_ma(dnb_attachment)
        # #     Dim iChildMA (2)
        # #     dnb_attachment.IsChildMA iChildMA
        # #     is_child_ma = iChildMA
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def is_parent_ma(self, i_parent_ma: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub IsParentMA(boolean iParentMA)
                | 
                |     Get whether the Parent is a Manufacturing Assembly
                | 
                |     Parameters:
                | 
                |         iParentMA
                |             TRUE if Parent is MA, FALSE otherwise 
                | 
                |     Returns:
                |         HRESULT indicate whether function succeeded. It fails if the Parent is
                |         not a Manufacturing Assembly

        :param bool i_parent_ma:
        :rtype: None
        """
        return self.dnb_attachment.IsParentMA(i_parent_ma)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'is_parent_ma'
        # # vba_code = """
        # # Public Function is_parent_ma(dnb_attachment)
        # #     Dim iParentMA (2)
        # #     dnb_attachment.IsParentMA iParentMA
        # #     is_parent_ma = iParentMA
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DnbAttachment(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DofState(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DOFState
                | 
                | Interface representing a Basic Device from which to get
                | DOFState.
                | 
                | Role: This interface is used to interact with devices DOF state that are
                | available in the Device Building workbench. This includes devices created in
                | both V5 and D5.
                | The following code snippet can be used to obtain a device in a CATProduct
                | document.
                | 
                |    Dim objDevice As DOFState
                |    set objDevice = CATIA.ActiveDocument.Product.GetTechnologicalObject("DOFState")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dof_state = com_object

    def get_device_dof_values(self, o_values: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetDeviceDOFValues(CATSafeArrayVariant oValues)
                | 
                |     Get the DOF values for the device.
                | 
                |     Parameters:
                | 
                |         oValues
                |             This contains a list of the current DOF values. Please note that
                |             distances are measured in meters and angles in radians.
                |
                |     Example:
                |
                |            Dim objDevice As DOFState
                |            set objDevice = CATIA.ActiveDocument.Product.GetTechnologicalObject("DOFState")
                |            Dim ListOfDOFValues () 
                |            objDevice.GetDeviceDOFValues ListOfDOFValues
                |            For i = 0 to ubound (ListOfDOFValues)
                |               ...
                |            Next

        :param tuple o_values:
        :rtype: None
        """
        return self.dof_state.GetDeviceDOFValues(o_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_device_dof_values'
        # # vba_code = """
        # # Public Function get_device_dof_values(dof_state)
        # #     Dim oValues (2)
        # #     dof_state.GetDeviceDOFValues oValues
        # #     get_device_dof_values = oValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DofState(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter
from pycatia.manufacturing_interfaces.manufacturing_tool_corrector import ManufacturingToolCorrector
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingTool(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingTool
                | 
                | A ManufacturingTool for a Manufacturing Document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_tool = com_object

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Comment() As CATBSTR (Read Only)
                | 
                |     Return the Default Comment of a Manufacturing Setup.
                | 
                |     Example:
                |         The following example return the comment ToolComment of to the
                |         manufacturing tool CurrentTool
                | 
                |          ToolComment=CurrentTool.Comment

        :rtype: str
        """

        return self.manufacturing_tool.Comment

    @property
    def corrector_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CorrectorCount() As short (Read Only)
                | 
                |     Retreive the number of correctors of a Manufacturing tool.
                | 
                |     Example:
                |         The following example retreives in CorrCount the number of tool
                |         correctors of tool CurrentTool
                | 
                |          Set NbCorr = CurrentTool.CorrectorCount

        :rtype: int
        """

        return self.manufacturing_tool.CorrectorCount

    @property
    def number_of_attributes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NumberOfAttributes() As short (Read Only)
                | 
                |     Give the Number og attributes of a Manufacturing Tool.
                | 
                |     Example:
                |         The following example returns the Number of attributes of the
                |         manufacturing Tool CurrentTool
                | 
                |          Number = CurrentTool.NumberOfAttributes

        :rtype: int
        """

        return self.manufacturing_tool.NumberOfAttributes

    @property
    def picture(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Picture() As CATBSTR (Read Only)
                | 
                |     Return the path where a picture of the parametrized tool is
                |     stored.
                | 
                |     Example:
                |         The following example return the path PicturePath where can be found
                |         the picture of the tool CurrentTool
                | 
                |          PicturePath=CurrentTool.Picture

        :rtype: str
        """

        return self.manufacturing_tool.Picture

    @property
    def tool_number(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ToolNumber() As long (Read Only)
                | 
                |     Give the Number linked to a Manufacturing Tool.
                | 
                |     Example:
                |         The following example returns the Number linked to the manufacturing
                |         Tool CurrentTool
                | 
                |          Number = CurrentTool.ToolNumber

        :rtype: int
        """

        return self.manufacturing_tool.ToolNumber

    @property
    def tool_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ToolType() As CATBSTR (Read Only)
                | 
                |     Return the technological type of a the tool.
                | 
                |     Example:
                |         The following example return the tool type ToolType of to the
                |         manufacturing tool CurrentTool
                | 
                |          Set ToolType=CurrentTool.ToolType

        :rtype: str
        """

        return self.manufacturing_tool.ToolType

    def add_corrector(self) -> ManufacturingToolCorrector:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddCorrector() As ManufacturingToolCorrector
                | 
                |     Adds a corrector to a Manufacturing tool.
                | 
                |     Example:
                |         The following example adds in Corr the tool corrector of Tool
                |         CurrentTool
                | 
                |          Set Corr = CurrentTool.AddCorrector

        :rtype: ManufacturingToolCorrector
        """
        return ManufacturingToolCorrector(self.manufacturing_tool.AddCorrector())

    def get_attribute(self, i_attribute: str) -> Parameter:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttribute(CATBSTR iAttribut) As Parameter
                | 
                |     Retrieve by is name the attribute of a Manufacturing Tool.
                |     Each attribute is a CKE object.
                | 
                |     Example:
                |         The following example retreives in Diameter the attribute MfgDiameter
                |         of the Manufacturing Tool firstTool
                | 
                |          Set Diameter = firstTool.GetAttribute(MfgDiameter)

        :param str i_attribute:
        :rtype: Parameter
        """
        return Parameter(self.manufacturing_tool.GetAttribute(i_attribute))

    def get_attribute_nls_name(self, i_attribute_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAttributeNLSName(CATBSTR iAttributName) As CATBSTR
                | 
                |     Retrieve the NLS name from the attribute name of a Manufacturing
                |     Tool.

        :param str i_attribute_name:
        :rtype: str
        """
        return self.manufacturing_tool.GetAttributeNLSName(i_attribute_name)

    def get_corrector(self, index: int) -> ManufacturingToolCorrector:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCorrector(short index) As
                | ManufacturingToolCorrector
                | 
                |     Retreive the corrector (index) of a Manufacturing tool.
                | 
                |     Example:
                |         The following example retreives in Corr the tool corrector of Tool
                |         CurrentTool
                | 
                |          Set Corr = CurrentTool.GetCorrector(index)

        :param int index:
        :rtype: ManufacturingToolCorrector
        """
        return ManufacturingToolCorrector(self.manufacturing_tool.GetCorrector(index))

    def get_list_of_apt_parameters(self, o_list_of_apt_parameters: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfAptParameters(CATSafeArrayVariant
                | oListOfAptParameters)
                | 
                |     Retrieve the list of apt definition parameters of a Manufacturing
                |     Tool.
                |     Parameters are returned in an array of real values.

        :param tuple o_list_of_apt_parameters:
        :rtype: None
        """
        return self.manufacturing_tool.GetListOfAptParameters(o_list_of_apt_parameters)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_apt_parameters'
        # # vba_code = """
        # # Public Function get_list_of_apt_parameters(manufacturing_tool)
        # #     Dim oListOfAptParameters (2)
        # #     manufacturing_tool.GetListOfAptParameters oListOfAptParameters
        # #     get_list_of_apt_parameters = oListOfAptParameters
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_attribute_units(self, o_list_of_attribute_units: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfAttributeUnits(CATSafeArrayVariant
                | oListOfAttributeUnits)
                | 
                |     Retrieve the list of attribute units of a Manufacturing
                |     Tool.
                |     The number of items in the output array is equal to the number of
                |     attributes of the tool.
                |     When an attribute has no unit definition, the corresponding unit item in
                |     the output array is a blank string.
                | 
                |     Example:
                |         The following example retrieves in TabAttributeUnits the list of
                |         attribute units of the Manufacturing Tool firstTool
                | 
                |          call
                |          firstTool.GetListOfAttributeUnits(TabAttributeUnits)

        :param tuple o_list_of_attribute_units:
        :rtype: None
        """
        return self.manufacturing_tool.GetListOfAttributeUnits(o_list_of_attribute_units)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_attribute_units'
        # # vba_code = """
        # # Public Function get_list_of_attribute_units(manufacturing_tool)
        # #     Dim oListOfAttributeUnits (2)
        # #     manufacturing_tool.GetListOfAttributeUnits oListOfAttributeUnits
        # #     get_list_of_attribute_units = oListOfAttributeUnits
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_attributes(self, o_list_of_attributes: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfAttributes(CATSafeArrayVariant
                | oListOfAttributes)
                | 
                |     Retrieve the list of attributes of a Manufacturing Tool.
                |     Each attribute is returned as the name of a CKE object.
                | 
                |     Example:
                |         The following example retrieves in TabAttributes the list of attributes
                |         of the Manufacturing Tool firstTool
                | 
                |          call firstTool.GetListOfAttributes(TabAttributes)

        :param tuple o_list_of_attributes:
        :rtype: None
        """
        return self.manufacturing_tool.GetListOfAttributes(o_list_of_attributes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_attributes'
        # # vba_code = """
        # # Public Function get_list_of_attributes(manufacturing_tool)
        # #     Dim oListOfAttributes (2)
        # #     manufacturing_tool.GetListOfAttributes oListOfAttributes
        # #     get_list_of_attributes = oListOfAttributes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_list_of_geom_attributes(self, o_list_of_attributes: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetListOfGeomAttributes(CATSafeArrayVariant
                | oListOfAttributes)
                | 
                |     Retrieve the list of geometry attributes of a Manufacturing
                |     Tool.
                |     Each attribute is returned as the name of a CKE object.
                | 
                |     Example:
                |         The following example retrieves in TabGeomAttributes the list of
                |         geometry attributes of the Manufacturing Tool
                |         firstTool
                | 
                |          call firstTool.GetListOfGeomAttributes(TabAttributes)

        :param tuple o_list_of_attributes:
        :rtype: None
        """
        return self.manufacturing_tool.GetListOfGeomAttributes(o_list_of_attributes)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_list_of_geom_attributes'
        # # vba_code = """
        # # Public Function get_list_of_geom_attributes(manufacturing_tool)
        # #     Dim oListOfAttributes (2)
        # #     manufacturing_tool.GetListOfGeomAttributes oListOfAttributes
        # #     get_list_of_geom_attributes = oListOfAttributes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ManufacturingTool(name="{self.name}")'
